Contract

Type Alias Contract 

pub type Contract = Consignment<false>;

Aliased Type

pub struct Contract {
    pub version: ContainerVer,
    pub transfer: bool,
    pub terminals: Confined<BTreeMap<BundleId, SecretSeals>, 0, 65535>,
    pub genesis: Genesis,
    pub bundles: Confined<Vec<WitnessBundle>, 0, 4294967295>,
    pub schema: Schema,
    pub types: TypeSystem,
    pub scripts: Confined<BTreeSet<Lib>, 0, 1024>,
}

Fields

version: ContainerVer

Version.

transfer: bool

Specifies whether the consignment contains information about state transfer (true), or it is just a consignment with an information about a contract.

terminals: Confined<BTreeMap<BundleId, SecretSeals>, 0, 65535>

Set of secret seals which are history terminals.

genesis: Genesis

Genesis data.

bundles: Confined<Vec<WitnessBundle>, 0, 4294967295>

All bundled state transitions contained in the consignment, together with their witness data.

schema: Schema

Schema (plus root schema, if any) under which contract is issued.

types: TypeSystem

Type system covering all types used in schema.

scripts: Confined<BTreeSet<Lib>, 0, 1024>

Collection of scripts used across consignment.