pub type Transfer = Consignment<true>;Aliased Type
pub struct Transfer {
pub version: ContainerVer,
pub transfer: bool,
pub terminals: Confined<BTreeMap<BundleId, SecretSeals>, 0, 65535>,
pub genesis: Genesis,
pub bundles: Confined<Vec<WitnessBundle>, 0, 4294967295>,
pub schema: Schema,
pub types: TypeSystem,
pub scripts: Confined<BTreeSet<Lib>, 0, 1024>,
}Fields
version: ContainerVerVersion.
transfer: boolSpecifies whether the consignment contains information about state transfer (true), or it is just a consignment with an information about a contract.
terminals: Confined<BTreeMap<BundleId, SecretSeals>, 0, 65535>Set of secret seals which are history terminals.
genesis: GenesisGenesis data.
bundles: Confined<Vec<WitnessBundle>, 0, 4294967295>All bundled state transitions contained in the consignment, together with their witness data.
schema: SchemaSchema (plus root schema, if any) under which contract is issued.
types: TypeSystemType system covering all types used in schema.
scripts: Confined<BTreeSet<Lib>, 0, 1024>Collection of scripts used across consignment.