pub struct Opcode { /* private fields */ }Expand description
A script Opcode.
We do not implement Ord on this type because there is no natural ordering on opcodes, but there
may appear to be one (e.g. because all the push opcodes appear in a consecutive block) and we
don’t want to encourage subtly buggy code. Please use Opcode::classify to distinguish different
types of opcodes.
Example of Core bug caused by assuming ordering
Bitcoin Core’s IsPushOnly considers OP_RESERVED to be a “push code”, allowing this opcode
in contexts where only pushes are supposed to be allowed.
Implementations