pub struct ScriptHashStats {
pub chain_stats: AddressTxsSummary,
pub mempool_stats: AddressTxsSummary,
}Expand description
Statistics about a particular Script hash’s confirmed and mempool transactions.
Fields
chain_stats: AddressTxsSummaryThe summary of confirmed Transactions for this Script hash.
mempool_stats: AddressTxsSummaryThe summary of mempool Transactions for this Script hash.