RgbInvoiceBuilder

Struct RgbInvoiceBuilder 

pub struct RgbInvoiceBuilder(/* private fields */);

Implementations

Source

impl RgbInvoiceBuilder

pub fn new(beneficiary: impl Into<XChainNet<Beneficiary>>) -> RgbInvoiceBuilder

pub fn with( contract_id: ContractId, beneficiary: impl Into<XChainNet<Beneficiary>>, ) -> RgbInvoiceBuilder

pub fn set_contract(self, contract_id: ContractId) -> RgbInvoiceBuilder

pub fn set_schema(self, schema_id: SchemaId) -> RgbInvoiceBuilder

pub fn set_assignment_name( self, assignment_name: impl Into<FieldName>, ) -> RgbInvoiceBuilder

pub fn set_void(self) -> RgbInvoiceBuilder

pub fn set_amount_raw(self, amount: impl Into<Amount>) -> RgbInvoiceBuilder

pub fn set_amount( self, integer: u64, decimals: u64, precision: Precision, ) -> Result<RgbInvoiceBuilder, RgbInvoiceBuilder>

pub fn set_allocation_raw( self, allocation: impl Into<Allocation>, ) -> RgbInvoiceBuilder

pub fn set_allocation( self, token_index: u32, fraction: u64, ) -> Result<RgbInvoiceBuilder, RgbInvoiceBuilder>

pub unsafe fn set_amount_approx( self, amount: f64, precision: Precision, ) -> Result<RgbInvoiceBuilder, RgbInvoiceBuilder>

Safety

The function may cause the loss of the information about the precise amount of the asset, since f64 type doesn’t provide full precision required for that.

pub fn set_expiry_timestamp(self, expiry: i64) -> RgbInvoiceBuilder

pub fn add_transport( self, transport: &str, ) -> Result<RgbInvoiceBuilder, (RgbInvoiceBuilder, TransportParseError)>

pub fn add_transport_raw(self, transport: RgbTransport) -> RgbInvoiceBuilder

pub fn add_transports<'a>( self, transports: impl IntoIterator<Item = &'a str>, ) -> Result<RgbInvoiceBuilder, (RgbInvoiceBuilder, TransportParseError)>

pub fn add_transports_raw( self, transports: impl IntoIterator<Item = RgbTransport>, ) -> RgbInvoiceBuilder

pub fn finish(self) -> RgbInvoice