ComposeError

Enum ComposeError 

pub enum ComposeError {
    NoExtraOrChange(AssignmentType),
    NoBeneficiaryOutput,
    BeneficiaryVout,
    InvoiceExpired,
    NoContract,
    InsufficientState,
    TooManyInputs,
    TooManyExtras,
    Builder(BuilderError),
}

Variants



NoExtraOrChange(AssignmentType)

no outputs available to store state of type {0}



NoBeneficiaryOutput

the provided PSBT doesn’t pay any sats to the RGB beneficiary address.



BeneficiaryVout

beneficiary output number is given when secret seal is used.



InvoiceExpired

expired invoice.



NoContract

the invoice contains no contract information.



InsufficientState

the invoice requirements can’t be fulfilled using available assets or smart contract state.



TooManyInputs

the spent UTXOs contain too many seals which can’t fit the state transition input limit.



TooManyExtras

the operation produces too many extra state transitions which can’t fit the container requirements.



Builder(BuilderError)