pub struct BlockStatus {
pub in_best_chain: bool,
pub height: Option<u32>,
pub next_best: Option<BlockHash>,
}Expand description
Information about a Blocks status.
Fields
in_best_chain: boolWhether this Block belongs to the chain with the most
Proof-of-Work (false for Blocks that belong to a stale chain).
height: Option<u32>The height of this Block.
next_best: Option<BlockHash>Trait Implementations
Sourceimpl Clone for BlockStatus
impl Clone for BlockStatus
Sourcefn clone(&self) -> BlockStatus
fn clone(&self) -> BlockStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockStatus
impl Debug for BlockStatus
Sourceimpl<'de> Deserialize<'de> for BlockStatus
impl<'de> Deserialize<'de> for BlockStatus
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockStatus, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockStatus, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BlockStatus
Sourceimpl PartialEq for BlockStatus
impl PartialEq for BlockStatus
impl StructuralPartialEq for BlockStatus