pub struct Txid(/* private fields */);Expand description
A bitcoin transaction hash/transaction ID.
For compatibility with the existing Bitcoin infrastructure and historical and current
versions of the Bitcoin Core software itself, this and other sha256d::Hash types, are
serialized in reverse byte order when converted to a hex string via std::fmt::Display
trait operations. See hashes::Hash::DISPLAY_BACKWARD for more details.
Implementations
Sourceimpl Txid
impl Txid
Sourcepub fn from_raw_hash(inner: Hash) -> Txid
pub fn from_raw_hash(inner: Hash) -> Txid
Creates this wrapper type from the inner hash type.
Sourcepub fn to_raw_hash(self) -> Hash
pub fn to_raw_hash(self) -> Hash
Returns the inner hash (sha256, sh256d etc.).
Sourcepub fn as_raw_hash(&self) -> &Hash
pub fn as_raw_hash(&self) -> &Hash
Returns a reference to the inner hash (sha256, sh256d etc.).