TypeSystem

Struct TypeSystem 

pub struct TypeSystem(/* private fields */);
Type system represents a set of strict types assembled from multiple libraries. It is designed to provide all necessary type information to analyze a type with all types it depends onto.

Type guarantees

  • Total number of types do not exceed 2^24-1;
  • Strict-serialized size is less than 2^24 bytes;
  • A type with the same semantic id can’t appear in more than 256 libraries;
  • Type system is complete (i.e. no type references a type which is not a part of the system).

Implementations

Source

impl TypeSystem

pub fn new() -> TypeSystem

pub fn count_types(&self) -> u24

pub fn get(&self, sem_id: SemId) -> Option<&Ty<SemId>>

pub fn extend(&mut self, other: TypeSystem) -> Result<(), Error>

pub fn extract( &self, ids: impl IntoIterator<Item = SemId>, ) -> Result<TypeSystem, UnknownType>

Source

impl TypeSystem

pub fn id(&self) -> TypeSysId

Source

impl TypeSystem

pub fn find(&self, sem_id: SemId) -> Option<&Ty<SemId>>

pub fn typify(&self, val: StrictVal, sem_id: SemId) -> Result<TypedVal, Error>

Source

impl TypeSystem

pub fn strict_deserialize_type( &self, sem_id: SemId, data: &[u8], ) -> Result<TypedVal, Error>

pub fn strict_read_type( &self, sem_id: SemId, d: &mut impl ReadRaw, ) -> Result<TypedVal, Error>

Source

impl TypeSystem

pub fn strict_serialize_value<const MAX_LEN: usize>( &self, typed: &TypedVal, ) -> Result<Confined<Vec<u8>, 0, MAX_LEN>, SerializeError>

pub fn strict_serialize_type<const MAX_LEN: usize>( &self, typed: &TypedVal, ) -> Result<SerializedType<MAX_LEN>, SerializeError>

👎Deprecated since 2.7.2:

use strict_serialize_value instead

pub fn strict_write_value( &self, typed: &TypedVal, writer: &mut impl Write, ) -> Result<(), Error>

pub fn strict_write_type( &self, typed: &TypedVal, writer: &mut impl Write, ) -> Result<(), Error>

👎Deprecated since 2.7.2:

use strict_write_value instead

Methods from Deref<Target = Confined<BTreeMap<SemId, Ty<SemId>>, amplify::::collection::confinement::MediumOrdMap::{constant#0}, amplify::::collection::confinement::MediumOrdMap::{constant#1}>>

pub fn as_inner(&self) -> &C

👎Deprecated since 4.7.0:

use as_unconfined method

Returns inner collection type

pub fn as_unconfined(&self) -> &C

Returns reference to the inner collection type.

pub fn to_inner(&self) -> C
where C: Clone,

👎Deprecated since 4.7.0:

use to_unconfined method

Clones inner collection type and returns it

pub fn to_unconfined(&self) -> C
where C: Clone,

Clones inner collection and returns an unconfined version of it.

pub fn len_u8(&self) -> u8

Returns number of elements in the confined collection as u8. The confinement guarantees that the collection length can’t exceed u8::MAX.

pub fn len_u16(&self) -> u16

Returns number of elements in the confined collection as u16. The confinement guarantees that the collection length can’t exceed u16::MAX.

pub fn len_u24(&self) -> u24

Returns number of elements in the confined collection as u24. The confinement guarantees that the collection length can’t exceed u24::MAX.

pub fn len_u32(&self) -> u32

Returns number of elements in the confined collection as u32. The confinement guarantees that the collection length can’t exceed u32::MAX.