Struct Gray_v08
struct Gray_v08<T>(447)
A Grayscale pixel (rgb crate v0.8)
Implementations
impl<T: Copy> Gray_v08<T>
fn value(self: Self) -> TReads the
.0fieldThis function isn't necessary, but it is forwards-compatible with the next major version of the RGB crate.
fn value_mut(self: &mut Self) -> &mut TExposes the
.0field for writingThis function isn't necessary, but it is forwards-compatible with the next major version of the RGB crate.
fn with_alpha(self: Self, add_alpha_value: T) -> GrayAlpha_v08<T>Add alpha component to this pixel
impl<T: Copy> Gray_v08<T>
const fn new(value: T) -> SelfCreates a new
Gray_v08pixel type from its components.Alternatively, you can use struct literal syntax to create the new pixel type:
use rgb::Gray_v08; let pixel = Gray_v08 {0 : value};
impl<P, T> Receiver for Gray_v08<T>
impl<T> Add for Gray_v08<T>
fn add(self: Self, r: T) -> <Self as >::Output
impl<T> AddAssign for Gray_v08<T>
fn add_assign(self: &mut Self, r: T)
impl<T> AddAssign for Gray_v08<T>
fn add_assign(self: &mut Self, other: Gray<T>)
impl<T> Any for Gray_v08<T>
fn type_id(self: &Self) -> TypeId
impl<T> AsMut for Gray<T>
fn as_mut(self: &mut Self) -> &mut T
impl<T> AsRef for Gray<T>
fn as_ref(self: &Self) -> &T
impl<T> Borrow for Gray_v08<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Gray_v08<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Gray_v08<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> ComponentSlice for Gray<T>
fn as_slice(self: &Self) -> &[T]fn as_mut_slice(self: &mut Self) -> &mut [T]
impl<T> Deref for Gray<T>
fn deref(self: &Self) -> &T
impl<T> Div for Gray_v08<T>
fn div(self: Self, r: T) -> <Self as >::Output
impl<T> DivAssign for Gray_v08<T>
fn div_assign(self: &mut Self, r: T)
impl<T> Freeze for Gray_v08<T>
impl<T> From for Gray_v08<T>
fn from(t: never) -> T
impl<T> From for Gray_v08<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Mul for Gray_v08<T>
fn mul(self: Self, r: T) -> <Self as >::Output
impl<T> MulAssign for Gray_v08<T>
fn mul_assign(self: &mut Self, r: T)
impl<T> MulAssign for Gray_v08<T>
fn mul_assign(self: &mut Self, other: Gray<T>)
impl<T> RefUnwindSafe for Gray_v08<T>
impl<T> Send for Gray_v08<T>
impl<T> StructuralPartialEq for Gray_v08<T>
impl<T> Sub for Gray_v08<T>
fn sub(self: Self, r: T) -> <Self as >::Output
impl<T> SubAssign for Gray_v08<T>
fn sub_assign(self: &mut Self, other: Gray<T>)
impl<T> SubAssign for Gray_v08<T>
fn sub_assign(self: &mut Self, r: T)
impl<T> Sum for Gray_v08<T>
fn sum<I: Iterator<Item = Self>>(iter: I) -> Self
impl<T> Sync for Gray_v08<T>
impl<T> Unpin for Gray_v08<T>
impl<T> UnsafeUnpin for Gray_v08<T>
impl<T> UnwindSafe for Gray_v08<T>
impl<T, U> Into for Gray_v08<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Gray_v08<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Gray_v08<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::clone::Clone> Clone for Gray_v08<T>
fn clone(self: &Self) -> Gray_v08<T>
impl<T: $crate::cmp::Eq> Eq for Gray_v08<T>
impl<T: $crate::cmp::Ord> Ord for Gray_v08<T>
fn cmp(self: &Self, other: &Gray_v08<T>) -> Ordering
impl<T: $crate::cmp::PartialEq> PartialEq for Gray_v08<T>
fn eq(self: &Self, other: &Gray_v08<T>) -> bool
impl<T: $crate::cmp::PartialOrd> PartialOrd for Gray_v08<T>
fn partial_cmp(self: &Self, other: &Gray_v08<T>) -> Option<Ordering>
impl<T: $crate::default::Default> Default for Gray_v08<T>
fn default() -> Gray_v08<T>
impl<T: $crate::fmt::Debug> Debug for Gray_v08<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T: $crate::hash::Hash> Hash for Gray_v08<T>
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl<T: $crate::marker::Copy> Copy for Gray_v08<T>
impl<T: Add> Add for Gray_v08<T>
fn add(self: Self, other: Gray<T>) -> <Self as >::Output
impl<T: Copy> From for Gray<T>
fn from(component: T) -> Self
impl<T: Copy, B> ColorComponentMap for Gray<T>
fn map_colors<F>(self: &Self, f: F) -> Gray<B> where F: FnMut(T) -> B
impl<T: Copy, B> ComponentMap for Gray<T>
fn map<F>(self: &Self, f: F) -> Gray<B> where F: FnMut(T) -> B
impl<T: Mul> Mul for Gray_v08<T>
fn mul(self: Self, other: Gray<T>) -> <Self as >::Output
impl<T: Sub> Sub for Gray_v08<T>
fn sub(self: Self, other: Gray<T>) -> <Self as >::Output